head, the
body, the interfoot, and the foot. Dust tables
also contain a table-wide attributes border_collapse and
longtable as well as a print_method element.dust(object, ..., tidy_df = FALSE, keep_rownames = FALSE,
glance_foot = FALSE, glance_stats = NULL, col_pairs = 2,
byrow = FALSE, descriptors = "term", numeric_level = c("term",
"term_plain", "label"))
redust(x, table, part = c("head", "foot", "interfoot", "body"))tidy method in broomtidyobject is an object that inherits the
data.frame class, the default behavior is to assume that the
object itself is the basis of the table. If the summarized table is
desired, set to TRUE.tidy_df is FALSE, setting
keep_rownames binds the row names to the data frame as the first
column, allowing them to be preserved in the tabulated output. This
is only to data frame like objects, as the foot of the
table. (Not scheduled for implementation until version 0.4.0)NULL, the default, all of the available
statistics are retrieved. In addition to controlling which statistics are
printed, this also controls the ordFALSE, that indicates if the
requested statistics are placed with priority to rows or columns.
See the full documentation for the unexported function glance_foot."term",
"term_plain", "label", "level", and
"level_detail". These may be used in any combina"level_detail" descriptor
when a numeric has an interaction with a factor. Acceptable inputs
are "term", "term_plain", and tabledustdust
object. This is intended to assist in building custom heads and feet.}head object describes what each column of the table
represents. By default, the head is a single row, but multi row headers
may be provided. Note that multirow headers may not render in markdown
or console output as intended, though rendering in HTML and LaTeX is
fairly reliable. In longtables (tables broken over multiple pages),
the head appears at the top of each table portion.
The body object gives the main body of information. In long tables,
this section is broken into portions, ideally with one portion per page.
The interfoot object is an optional table to be placed at the
bottom of longtable portions with the exception of the last portion. A
well designed interfoot can convey to the user that the table
continues on the next page.
The foot object is the table that appears at the end of the
completed table. For model objects, it is recommended that the
glance statistics be used to display model fit
statistics.
The border_collapse object applies to an entire HTML table. It
indicates if the borders should form a single line or distinct lines.
The longtable object determines how many rows per page are printed.
By default, all content is printed as a single table. Using the
longtable argument in the sprinkle function can change this
setting.
The print_method object determines how the table is rendered when
the print method is invoked. The default is to print to the
console.tidy glance_foot tidy_levels_labelsx <- dust(lm(mpg ~ qsec + factor(am), data = mtcars))
xRun the code above in your browser using DataLab