head, the
body, the interfoot, and the foot. Dust tables
also contain a table_attributes object and a print_method
object.dust(object, ..., glance_foot = TRUE, tidy_df = FALSE)tidy method in broomtidyfoot of the
table. (Not scheduled for implementation until version 0.4.0)object is an object that inherits the
data.frame class, the default behavior is to assume that the
object itself is the basis of the table. If the summarized table is
desired, set to TRUE.dustdust
object. This is intended to assist in building custom heads and feet.}head object describes what each column of the table
represents. By default, the head is a single row, but multi row headers
may be provided. Note that multirow headers may not render in markdown
as intended, though rendering in HTML and LaTeX is fairly reliable. In
longtables (tables broken over multiple pages), the head appears
at the top of each table portion. The body object gives the main body of information. In long tables,
this portion is broken into portions, ideally with one portion per page.
The interfoot object is an optional table to be placed at the
bottom of longtable portions with the exception of the last portion. A
well designed interfoot can convey to the user that the table
continues on the next page.
The foot object is the table that appears at the end of the
completed table. For model objects, it is recommended that the
glance statistics be used to display model fit
statistics.
The table_attributes object stores information to apply to the
entire table.
The print_method object determines how the table is rendered when
the print method is invoked. The default is to print to the
console.
x <- dust(lm(mpg ~ qsec + factor(am), data = mtcars))
xRun the code above in your browser using DataLab